@@ -1,8 +1,9 @@
-__version__ = "1.0.2"
+__version__ = "1.0.5"
 
 import dataclasses
 import hashlib
 import json
+import time
 from datetime import datetime, date
 from pathlib import Path
 from typing import Union
@@ -22,6 +23,14 @@ def ansi_rgb(r: int, g: int, b: int, foreground: bool = True) -> str:
     return f'\033[{c};2;{r};{g};{b}m'
 
 
+replacements = ["&0/\033[0;30m", "&1/\033[0;34m", "&2/\033[0;32m", "&3/\033[0;36m", "&4/\033[0;31m",
+                "&5/\033[0;35m", "&6/\033[0;33m", "&7/\033[0;37m", "&8/\033[1;30m", "&9/\033[1;34m",
+                "&a/\033[1;32m", "&b/\033[1;36m", "&c/\033[1;31m", "&d/\033[1;35m", "&e/\033[1;33m",
+                "&f/\033[1;37m",
+                "&r/\033[0m", "&l/\033[1m", "&o/\033[3m", "&n/\033[4m", "&-/\n"]
+replacements = [(r[:2], r[3:]) for r in replacements]
+
+
 def color(msg: str) -> str:
     """
     Replace extended minecraft color codes in string
@@ -29,9 +38,8 @@ def color(msg: str) -> str:
     :param msg: Message with minecraft color codes
     :return: Message with escape codes
     """
-    replacements = ["&0/\033[0;30m", "&1/\033[0;34m", "&2/\033[0;32m", "&3/\033[0;36m", "&4/\033[0;31m", "&5/\033[0;35m", "&6/\033[0;33m", "&7/\033[0;37m", "&8/\033[1;30m", "&9/\033[1;34m", "&a/\033[1;32m", "&b/\033[1;36m", "&c/\033[1;31m", "&d/\033[1;35m", "&e/\033[1;33m", "&f/\033[1;37m", "&r/\033[0m", "&n/\n"]
-    for r in replacements:
-        msg = msg.replace(r[:2], r[3:])
+    for code, esc in replacements:
+        msg = msg.replace(code, esc)
 
     while '&gf(' in msg or '&gb(' in msg:
         i = msg.index('&gf(') if '&gf(' in msg else msg.index('&gb(')
@@ -173,3 +181,22 @@ def md5(file: Union[str, Path]) -> str:
         for chunk in iter(lambda: f.read(4096), b""):
             hash_md5.update(chunk)
     return hash_md5.hexdigest()
+
+
+class Timer:
+    start: int
+
+    def __init__(self):
+        self.reset()
+
+    def elapsed(self, reset: bool = True) -> float:
+        t = (time.time_ns() - self.start) / 1000000
+        if reset:
+            self.reset()
+        return t
+
+    def log(self, *args):
+        print(f'{self.elapsed():.0f}ms', *args)
+
+    def reset(self):
+        self.start = time.time_ns()
